<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://modeltheme.com/
 * @since      1.0.0
 *
 * @package    Mt_Wfvl_Woocommerce_Fake_Variation_Links
 * @subpackage Mt_Wfvl_Woocommerce_Fake_Variation_Links/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Mt_Wfvl_Woocommerce_Fake_Variation_Links
 * @subpackage Mt_Wfvl_Woocommerce_Fake_Variation_Links/admin
 * @author     ModelTheme <support@modeltheme.com>
 */
class Mt_Wfvl_Woocommerce_Fake_Variation_Links_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		global $pagenow; 


		if ( ( 'admin.php' === $pagenow ) && ( 'mt_wfvl_options' === $_GET['page'] ) ) {
    		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/mt-woocommerce-fake-variation-links-admin.css', array(), $this->version, 'all' );
			wp_enqueue_style( 'bootstrap', plugin_dir_url( __FILE__ ) . 'css/dataTables.bootstrap5.min.css');
            wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_style( 'select2', plugin_dir_url( __FILE__ ) . 'css/select2.css');
		}

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		global $pagenow; 


		if ( ( 'admin.php' === $pagenow ) && ( 'mt_wfvl_options' === $_GET['page'] ) ) {
            wp_enqueue_media();
    		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/mt-woocommerce-fake-variation-links-admin.js', array( 'jquery', 'wp-color-picker' ), $this->version, false );
			wp_enqueue_script( 'datatables', plugin_dir_url( __FILE__ ) . 'js/jquery.dataTables.min.js', array( 'jquery' ), '1.10.24', 'all' );
			wp_enqueue_script( 'dataTables.bootstrap', plugin_dir_url( __FILE__ ) . 'js/dataTables.bootstrap5.min.js', array( 'jquery' ), 'v4.6.0', 'all' );
            wp_enqueue_script( 'select2', plugin_dir_url( __FILE__ ) . 'js/select2.min.js', array( 'jquery' ), '4.1.0', 'all' );
		}

	}

	//create "MT Plugins" menu item page
	public function mt_wfvl_add_menu_page() {
        if ( !empty ( $GLOBALS['admin_page_hooks']['mt_plugins'] ) ) {
            return;
        }

        add_menu_page(
            esc_html__("MT Plugins", "mt_wfvl"), esc_html__("MT Plugins", "mt_wfvl"), "NULL", "mt_plugins", array($this, "sc_menu_page"), "", 3611
        );
    }

    //create "MT Woocommerce Fake Variations" menu item page
    public function mt_wfvl_add_submenu_pages() {
        add_submenu_page(
            "mt_plugins",
             esc_html__("MT Woocommerce Fake Variations", "mt_wfvl"),
             esc_html__("MT Woocommerce Fake Variations", "mt_wfvl"),
            "manage_options",
            "mt_wfvl_options",
            array($this, "mt_wfvl_options_page")
        );
    }

	//inside "MT Woocommerce Fake Variations" page
    public function mt_wfvl_options_page() {
    	global $mt_wfvl_active_tab;
		$mt_wfvl_active_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : 'general'; 

		do_action('before_mt_wfvl_fake_variations_tabs'); ?>
        <div class="wrap">
	        	<?php do_action('mt_wfvl_fake_variations_tabs_title'); ?>
        	<nav class="nav-tab-wrapper">
	        	<?php do_action('mt_wfvl_fake_variations_tabs_head'); ?>
        	</nav>
        	<div class="mt_wfvl_tabs_content">
	        	<?php do_action('mt_wfvl_fake_variations_tabs_content'); ?>
        	</div>
        </div>
	<?php }

	//function responsible for displaying the fake variations settings page title
    function mt_wfvl_fake_variation_title(){ ?>
    	<h2 style="font-weight: 500;"><?php echo esc_html__("MT Woocommerce Fake Variations Settings", "mt_wfvl"); ?></h2>
    <?php }

    //function responsible for edditing the fake variation product dropdown fields
    public function mt_wfvl_products_name_droptdown($args) {
    	$products_args = array(
    		'post_type'			=>'product',
    		'posts_per_page'	=> -1,
		    'order' => 'ASC',
		    'orderby' => 'title',
		    'post_status' => 'publish'
    	);

    	$products_array = array();
    	$products_query = new WC_Product_Query( $products_args);
		$products = $products_query->get_products();

        echo '<select id="'. esc_attr($args['name']) .'" name="'. esc_attr($args['name']) .'">';
		foreach ($products as $product) {
	        echo '<option value="'.esc_attr($product->get_id()).'" ' . ($args['value'] == $product->get_id() ? 'selected' : '') . '>' . esc_html__($product->get_name()) . '</option>';
		}
        echo '</select>';
    	echo '<p class="description"> '.esc_html($args['description']).'</p>';
    }

    //function responsible for edditing the fake variation front end location dropdown
    public function mt_wfvl_fake_variations_location($args) {
    	$fake_variations_locations = array('woocommerce_before_add_to_cart_form' => 'Before add to cart form', 'woocommerce_before_variations_form' => 'Before variation form', 'woocommerce_before_add_to_cart_button' => 'Before add to cart button', 'woocommerce_after_add_to_cart_button' => 'After add to cart button', 'woocommerce_product_meta_end' => 'Product meta end', 'woocommerce_share' => 'Share' );

        echo '<select id="'. esc_attr($args['name']) .'" name="'. esc_attr($args['name']) .'">';
		foreach ($fake_variations_locations as $hook => $text ) {
	        echo '<option value="'.esc_attr($hook).'" '.(get_option('fake_variation_hook') == $hook ? 'selected' : '').'>' . esc_html__($text) . '</option>';
		}
        echo '</select>';
    	echo '<p class="description"> '.esc_html($args['description']).'</p>';
    }

    //function responsible for edditing the fake variation front end type
    public function mt_wfvl_fake_variations_type($args) {
        $fake_variations_type = array( esc_html('text') => esc_html__('Text'), esc_html('image') => esc_html__('Image'), esc_html('color') => esc_html__('Color') );

        echo '<select id="'. esc_attr($args['name']) .'" name="'. esc_attr($args['name']) .'">';
        foreach ($fake_variations_type as $value => $type ) {
            echo '<option value="'.esc_attr($value).'">' . esc_html__($type) . '</option>';
        }
        echo '</select>';
        echo '<p class="description"> '.esc_html($args['description']).'</p>';
    }

    //function responsible for edditing the fake variation input type text fields
    public function mt_wfvl_fake_variations_image($args) { ?>
        <div class='image-preview-wrapper'>
            <img class='image-preview' src='' width='100' height='100' style='max-height: 100px; width: 100px;'>
        </div>
        <input type="button" class="button upload_image_button" value="<?php _e( 'Upload image' ); ?>" />
        <input type='hidden' name='<?php echo esc_attr($args['name']); ?>' id='<?php echo esc_attr($args['name']); ?>' value=''>
        <p class="description"><?php echo esc_html($args['description']);?></p>

    <?php }

    //function responsible for edditing the fake variation input type text fields
    public function mt_wfvl_fake_variations_color($args) { ?>
        <input type="text" name="<?php echo esc_attr($args['name']);?>" id="<?php echo esc_attr($args['name']);?>" value="#bada55" class="my-color-field" data-default-color="#effeff">
        <p class="description"><?php echo esc_html($args['description']);?></p>
    <?php }

    //function responsible for edditing the fake variation input type text fields
    public function mt_wfvl_render_input_type_text($args) { ?>
    	<input type="text" name="<?php echo esc_attr($args['name']);?>">
    	<p class="description"><?php echo esc_html($args['description']);?></p>
    <?php }

    //function responsible for edditing the fake variation input type checkbox fields
    public function mt_wfvl_render_input_type_checkbox($args) { ?>
    	<input type="checkbox" name="<?php echo esc_attr($args['name']);?>" value="inactive">
    	<p class="description"><?php echo esc_html($args['description']);?></p>
    <?php }

    //function responsible for creating the "Add new fake variation" form fields
    public function mt_wfvl_register_settings() {

        add_settings_section(
            "mt_wfvl_settings",
            esc_html__("Add New Fake Variation", "mt_wfvl"),
            null,
            "mt_wfvl_settings"
        );

        add_settings_field(
            "mt_wfvl_product_id",
            esc_html__("Product name", "mt_wfvl"),
            array($this, "mt_wfvl_products_name_droptdown"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name"          => "mt_wfvl_product_id",
                "description"   => esc_html__("The name of the product that you want to add a fake variation to.", "mt_wfvl"),
                "value"         => ""
            ]
        );

        add_settings_field(
            "mt_wfvl_attribute_name",
            esc_html__("Attribute name", "mt_wfvl"),
            array($this, "mt_wfvl_render_input_type_text"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name" => "mt_wfvl_attribute_name",
                "description" => esc_html__("The name of the attribute for which the variation stands for. Example: Capacity", "mt_wfvl"),
            ]
        );

        add_settings_field(
            "mt_wfvl_fake_variation",
            esc_html__("Fake Variation Product", "mt_wfvl"),
            array($this, "mt_wfvl_products_name_droptdown"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name" => "mt_wfvl_fake_variation",
                "description" => esc_html__("The name of the product that you want to be the fake variation.", "mt_wfvl"),
                "value"         => ""
            ]
        );

        add_settings_field(
            "mt_wfvl_fake_variation_name",
            esc_html__("Fake Variation Label", "mt_wfvl"),
            array($this, "mt_wfvl_render_input_type_text"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name" => "mt_wfvl_fake_variation_name",
                "description" => esc_html__("The label that will be seen in front end. Example: 64GB", "mt_wfvl"),
            ]
        );

        add_settings_field(
            "mt_wfvl_fake_variation_type",
            esc_html__("Fake Variation Type", "mt_wfvl"),
            array($this, "mt_wfvl_fake_variations_type"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name" => "mt_wfvl_fake_variation_type",
                "description" => esc_html__("The type of the fake variation that will be seen in front end.", "mt_wfvl"),
            ]
        );

        add_settings_field(
            "mt_wfvl_fake_variation_image",
            esc_html__("Fake Variation Image", "mt_wfvl"),
            array($this, "mt_wfvl_fake_variations_image"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name" => "mt_wfvl_fake_variation_image",
                "description" => esc_html__("The image of the fake variation that will be seen in front end.", "mt_wfvl"),
                "class" => "hidden",
            ]
        );

        add_settings_field(
            "mt_wfvl_fake_variation_color",
            esc_html__("Fake Variation Color", "mt_wfvl"),
            array($this, "mt_wfvl_fake_variations_color"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name" => "mt_wfvl_fake_variation_color",
                "description" => esc_html__("The color of the fake variation that will be seen in front end.", "mt_wfvl"),
                "class" => "hidden",
            ]
        );


        add_settings_field(
            "mt_wfvl_fake_variation_inactive",
            esc_html__("Fake Variation Inactive", "mt_wfvl"),
            array($this, "mt_wfvl_render_input_type_checkbox"),
            "mt_wfvl_settings",
            "mt_wfvl_settings",
            [
                "name" => "mt_wfvl_fake_variation_inactive",
                "description" => esc_html__("By checking this checkbox you will set the fake variation as inactive.", "mt_wfvl"),
            ]
        );
    }

    //function responsible for creating the "Select the fake variations location" form fields
    public function mt_wfvl_register_setting_hook() {
        register_setting( "mt_wfvl_settings_hook", "fake_variation_hook" );
    	add_settings_section(
            "mt_wfvl_settings_hook",
            esc_html__("Select the fake variations location", "mt_wfvl"),
            null,
            "mt_wfvl_settings_hook"
        );
        add_settings_field(
            "fake_variation_hook",
            esc_html__("Fake Variations Location", "mt_wfvl"),
            array($this, "mt_wfvl_fake_variations_location"),
            "mt_wfvl_settings_hook",
            "mt_wfvl_settings_hook",
            [
                "name" => "fake_variation_hook",
                "description" => esc_html__("The position of the fake variations in the single product page.", "mt_wfvl"),
            ]
        );
    }

	//fake variation tab head
	function mt_wfvl_tab_head_add_new(){
		global $mt_wfvl_active_tab; ?>
		<a class="nav-tab <?php echo $mt_wfvl_active_tab == 'add_new' || '' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url( 'admin.php?page=mt_wfvl_options&tab=add_new' ); ?>"><?php esc_html_e( 'Fake Variations', 'sd' ); ?> </a>
		<?php
	}
	//function responsible for tab content for fake variations tab
    function mt_wfvl_tab_add_new() { 
    	global $mt_wfvl_active_tab;
		if ( '' || 'add_new' != $mt_wfvl_active_tab )
			return;
		?>

    	<div id="mt_wfvl_new_fake_variations" calss="mt_wfvl_tab_content">
	    	<form class="scpotw-settings" method="post">
	        	<!-- new variation form fields -->
	            <?php settings_fields( "mt_wfvl_settings" ); ?>
	            <?php do_settings_sections( "mt_wfvl_settings" ); ?>
	            <?php submit_button(esc_html__('Submit Fake Variation', "mt_wfvl"),'primary','submit_fake_variation'); ?>
	        </form>

        		<!-- fake variations table -->
	        <?php $this->mt_wfvl_fake_variations_table(); ?>

	        <!-- edit fake variation modal -->
	        <?php $this->mt_wfvl_fake_variations_edit_modal(); ?>
    	</div>
    <?php }

    //import/export tab head
	function mt_wfvl_tab_head_import_export(){
		global $mt_wfvl_active_tab; ?>
		<a class="nav-tab <?php echo $mt_wfvl_active_tab == 'import_export' || '' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url( 'admin.php?page=mt_wfvl_options&tab=import_export' ); ?>"><?php esc_html_e( 'Import/Export', 'mt_wfvl' ); ?> </a>
		<?php
	}

	//import export tab content
    function mt_wfvl_tab_import_export() {  
    	global $mt_wfvl_active_tab;
		if ( '' || 'import_export' != $mt_wfvl_active_tab )
			return;
		?>
	    	<!-- export section -->
        <?php $this->mt_wfvl_fake_variations_export(); ?>
        	<!-- import import -->
        <?php $this->mt_wfvl_fake_variations_import(); ?>

    	<?php 
	}

    //function responsible for displaying export form
    function mt_wfvl_fake_variations_export() {?>
    	<form class="scpotw-settings" method="post">
    		<h2><?php esc_html_e("Export Fake Variations in csv file format.", "mt_wfvl") ?></h2>
        	<!-- export button -->
            <?php submit_button(esc_html__('Export', "mt_wfvl"),'','export-fake_variations',false); ?>
            <p class="description"><?php esc_html_e("The exported file will be in .csv format. The values inside will be comma separated.", "mt_wfvl") ?></p>
        </form>
    <?php }

    //function responsible for displaying import form
    function mt_wfvl_fake_variations_import() { ?>
		<form method='post' action='<?= esc_url($_SERVER['REQUEST_URI']); ?>' enctype='multipart/form-data' class="scpotw-settings import_csv">
			<h2><?php echo esc_html__("Import Fake Variations", "mt_wfvl") ?></h2>
	    	<input type="file" name="import-fake_variations">
            <?php submit_button(esc_html__('Import', "mt_wfvl"),'','butimport_fake_variations',false); ?>
            <p class="description"><?php esc_html_e("The imported file must be in .csv format, and the data inside must be separated by comma. Any other file format will not be accepted. Each data row must contain product id, attribute name, linked product id, variation label, status, and date. The status can either be active or inactive. The date format must be: \"2021-03-31\".", "mt_wfvl") ?></p>
	  	</form>
    <?php }

    //function responsible for creating the export file
    function mt_wfvl_export_fake_variations() {
        if( isset( $_POST['export-fake_variations'] ) ) {
            global $wpdb;
            $results = $wpdb->get_results( 
                "SELECT * FROM ".$wpdb->prefix."mt_woocommerce_fake_variations",
                OBJECT
            );
            if ($results) {
      
                header('Content-type: text/csv');
                header('Content-Disposition: attachment; filename="fake-variations-export.csv"');
                header('Pragma: no-cache');
                header('Expires: 0');
      
                $file = fopen('php://output', 'w');
      
                fputcsv($file, array('Product ID', 'Product SKU', 'Attribute name', 'Fake Variation Product ID', 'Fake Variation Product SKU', 'Fake Variation Name', 'Fake Variation Type', 'Fake Variation Color', 'Fake Variation Image','Fake Variation Inactive','Date'));
      
                foreach ($results as $row) {
                    
      
                    fputcsv($file, array($row->product_id, wc_get_product($row->product_id)->get_sku(), $row->attribute_name, $row->fake_variation_product_id, wc_get_product($row->fake_variation_product_id)->get_sku(), $row->fake_variation_product_name, $row->mt_wfvl_fake_variation_type, $row->mt_wfvl_fake_variation_color, $row->mt_wfvl_fake_variation_image, $row->status, $row->time));
                }
      
                exit();
            }
        }
    }

    function mt_wfvl_get_product_by_sku( $sku ) {
            
        global $wpdb;
        $product_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_sku' AND meta_value='%s' LIMIT 1", $sku ) );
        
        if ( $product_id ) return $product_id;
        return null;
    }    

	//function responsible for processing the import file
    function mt_wfvl_import_fake_variatons() {

        global $wpdb;
        // Table name
        $table_name = $wpdb->prefix . "mt_woocommerce_fake_variations";
        // Import CSV
        if(isset($_POST['butimport_fake_variations'])){
            // NOTICE! Understand what this does before running. 
            $existing_products = wc_get_products(array('posts_per_page' => -1, 'post_status'=>'publish')); 
            $product_IDs = array();

            foreach ($existing_products as $product) {
                $product_IDs[] = $product->id;
            }
            // File extension
            $extension = pathinfo($_FILES['import-fake_variations']['name'], PATHINFO_EXTENSION);
            // If file extension is 'csv'
            if(!empty($_FILES['import-fake_variations']['name']) && $extension == 'csv'){
                $totalInserted = 0;
                // Open file in read mode
                $csvFile = fopen($_FILES['import-fake_variations']['tmp_name'], 'r');
                fgetcsv($csvFile); // Skipping header row
                // Read file
                while(($csvData = fgetcsv($csvFile)) !== FALSE){
                    // Row column length
                    $dataLen = count($csvData);
                    // Assign value to variables
                    $product_id = $csvData[0];
                    $product_SKU = $csvData[1];
                    $attribute_name = $csvData[2];
                    $fake_variation_product_id = $csvData[3];
                    $fake_variation_product_SKU = $csvData[4];
                    $fake_variation_product_name = $csvData[5];
                    $mt_wfvl_fake_variation_type = $csvData[6];
                    $mt_wfvl_fake_variation_color = $csvData[7];
                    $mt_wfvl_fake_variation_image = $csvData[8];
                    $status =  $csvData[9];
                    $date =  $csvData[10];
                    // Check record already exists or not
                    $is_matching = 0;
                    $results = $wpdb->get_results( 
                        "SELECT * FROM ".$table_name."",
                        OBJECT
                    );
                    foreach ($results as $row) {
                        if( $row->product_id == $product_id && $row->attribute_name == $attribute_name && $row->fake_variation_product_id == $fake_variation_product_id && $row->fake_variation_product_name == $fake_variation_product_name && $row->status == $status && $row->mt_wfvl_fake_variation_type == $mt_wfvl_fake_variation_type && $row->mt_wfvl_fake_variation_image == $mt_wfvl_fake_variation_image && $row->mt_wfvl_fake_variation_color == $mt_wfvl_fake_variation_color) {
                            $is_matching = 1; 
                        }
                    }

                    if (!in_array($product_id, $product_IDs)) {
                        $product_id = $this->mt_wfvl_get_product_by_sku( $product_SKU );
                    }

                    if (!in_array($fake_variation_product_id, $product_IDs)) {
                        $fake_variation_product_id = $this->mt_wfvl_get_product_by_sku( $fake_variation_product_SKU );
                    }

                    //check if the ids are product ids
                    if(in_array($product_id, $product_IDs) && in_array($fake_variation_product_id, $product_IDs)) {
                        // Check if variable is empty or not
                        if($product_id && $attribute_name && $fake_variation_product_id && $fake_variation_product_name && $status && $date && $is_matching !=1 ) {
                            // Insert Record
                            $wpdb->insert($table_name, array(
                                'product_id'                   => $product_id,
                                'attribute_name'               => $attribute_name,
                                'fake_variation_product_id'    => $fake_variation_product_id,
                                'fake_variation_product_name'  => $fake_variation_product_name,
                                'status'                       => $status,
                                'time'                         => $date,
                                'mt_wfvl_fake_variation_type'  => $mt_wfvl_fake_variation_type,
                                'mt_wfvl_fake_variation_color' => ($mt_wfvl_fake_variation_color) ? $mt_wfvl_fake_variation_color : '',
                                'mt_wfvl_fake_variation_image' => ($mt_wfvl_fake_variation_image) ? $mt_wfvl_fake_variation_image : '',
                            ));
                            if($wpdb->insert_id > 0){
                                $totalInserted++;
                            }   
                        }
                    } elseif( !$product_id ) { ?>
                        <div class="notice notice-warning is-dismissible">
                            <p><?php esc_html_e("The product with the SKU: ".$product_SKU." does not exist", "mt_wfvl");?></p>
                        </div>
                    <?php } elseif( !$fake_variation_product_id ) { ?>
                        <div class="notice notice-warning is-dismissible">
                            <p><?php esc_html_e("The product with the SKU: ".$fake_variation_product_SKU." does not exist", "mt_wfvl");?></p>
                        </div>
                    <?php } elseif( !in_array($product_id, $product_IDs) ) { ?>
                        <div class="notice notice-warning is-dismissible">
                            <p><?php esc_html_e("The product with the ID: ".$product_id." does not exist", "mt_wfvl");?></p>
                        </div>
                    <?php } elseif( !in_array($fake_variation_product_id, $product_IDs) ) { ?>
                        <div class="notice notice-warning is-dismissible">
                            <p><?php esc_html_e("The product with the ID: ".$fake_variation_product_id." does not exist", "mt_wfvl");?></p>
                        </div>
                    <?php }
                } 
                //head of the page success notice
                add_action('admin_notices', function ($content) use ($totalInserted) {
                    //$my_param is available for you now ?>
                    <div class="notice notice-success is-dismissible">
                        <p><?php esc_html_e("Total Fake Variation Inserted : ".$totalInserted, "mt_wfvl");?></p>
                    </div>
                <?php }, 10, 1);
            }else{
                //head of the page fail notice
                add_action('admin_notices', function () { ?>
                    <div class="notice notice-warning is-dismissible">
                        <p><?php esc_html_e("Invalid file!", "mt_wfvl");?></p>
                    </div>
                <?php }, 10, 1);

            }
        }
    }

	//function responsible for displaying the general tab head
    function mt_wfvl_tab_head_general(){
		global $mt_wfvl_active_tab; ?>
		<a class="nav-tab <?php echo $mt_wfvl_active_tab == 'general' || '' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url( 'admin.php?page=mt_wfvl_options&tab=general' ); ?>"><?php esc_html_e( 'General', 'mt_wfvl' ); ?> </a>
		<?php
	}

	//function responsible for displaying the general tab content
    function mt_wfvl_tab_general() {  
    	global $mt_wfvl_active_tab;
		if ( '' || 'general' != $mt_wfvl_active_tab )
			return;
		?>
    	<form method='post' action='<?= esc_url($_SERVER['REQUEST_URI']); ?>' enctype='multipart/form-data' class="scpotw-settings">
    		<?php settings_fields( "mt_wfvl_settings_hook" ); ?>
            <?php do_settings_sections( "mt_wfvl_settings_hook" ); ?>
            <?php submit_button(esc_html__('Submit', "mt_wfvl"),'primary'); ?>
    	</form>
    <?php }

	//function responsible for saving the fake variations front end location
    function mt_wfvl_fake_variation_set_location() {
    	if(isset($_POST['fake_variation_hook'])) {
	    	if (!$this->option_exists("fake_variation_hook")) {
			    add_option("fake_variation_hook", $_POST['fake_variation_hook']);
			} else {
		        update_option( 'fake_variation_hook', $_POST['fake_variation_hook']);
			}?>
			<div class="notice notice-success is-dismissible">
				<p><?php echo esc_html__("You have succesfuly changed the location for the Fake Variations.", "mt_wfvl");?></p>
			</div>

    	<?php }
    }

	//function responsible for checking if the option exists
    public function option_exists($name, $site_wide=false){
	    global $wpdb; 
	    return $wpdb->query("SELECT * FROM ". ($site_wide ? $wpdb->base_prefix : $wpdb->prefix). "options WHERE option_name ='$name' LIMIT 1");
	}

    // save the new fake variation values
    function mt_wfvl_save_fake_variation() {

    	//load global wpdb
    	global $wpdb;
        $table_name = $wpdb->prefix . "mt_woocommerce_fake_variations";


    	if(isset($_POST['submit_fake_variation'])) {

	    	//check if the fields were filed in
	        if (isset($_POST["mt_wfvl_product_id"])) {
	        	$mt_wfvl_product_id = $_POST["mt_wfvl_product_id"];
	        }
	        if (isset($_POST["mt_wfvl_attribute_name"])) {
	        	$mt_wfvl_attribute_name = $_POST["mt_wfvl_attribute_name"];
	        }
	        if (isset($_POST["mt_wfvl_fake_variation"])) {
	        	$mt_wfvl_fake_variation = $_POST["mt_wfvl_fake_variation"];
	        }
	        if (isset($_POST["mt_wfvl_fake_variation_name"])) {
	        	$mt_wfvl_fake_variation_name = $_POST["mt_wfvl_fake_variation_name"];
	        }
            if (isset($_POST["mt_wfvl_fake_variation_type"])) {
                $mt_wfvl_fake_variation_type = $_POST["mt_wfvl_fake_variation_type"];
            }
            if (isset($_POST["mt_wfvl_fake_variation_color"]) && $mt_wfvl_fake_variation_type == "color" ) {
                $mt_wfvl_fake_variation_color = $_POST["mt_wfvl_fake_variation_color"];
            }
            if (isset($_POST["mt_wfvl_fake_variation_image"]) && $mt_wfvl_fake_variation_type == "image" ) {
                $mt_wfvl_fake_variation_image = $_POST["mt_wfvl_fake_variation_image"];
            }
	        if (isset($_POST["mt_wfvl_fake_variation_inactive"])) {
	        	$mt_wfvl_fake_variation_inactive = $_POST["mt_wfvl_fake_variation_inactive"];
	        } else {
	        	$mt_wfvl_fake_variation_inactive = 'active';
	        }

	        //check if user is trying to add an entry that allready exists
	    	$results = $wpdb->get_results( 
	    		"SELECT * FROM ".$table_name."",
	    		OBJECT
	    	);
			$is_matching = 0;

			foreach ($results as $row) {
				if( $row->product_id == $_POST["mt_wfvl_product_id"] && $row->attribute_name == $_POST["mt_wfvl_attribute_name"] && $row->fake_variation_product_id == $_POST["mt_wfvl_fake_variation"] && $row->fake_variation_product_name == $_POST["mt_wfvl_fake_variation_name"] && $row->mt_wfvl_fake_variation_type == $_POST["mt_wfvl_fake_variation_type"] && $row->mt_wfvl_fake_variation_color == $_POST["mt_wfvl_fake_variation_color"] && $row->mt_wfvl_fake_variation_image == $_POST["mt_wfvl_fake_variation_image"] ) {
					$is_matching = 1; 

				}
			}

			if ($mt_wfvl_product_id && $mt_wfvl_attribute_name && $mt_wfvl_fake_variation && $mt_wfvl_fake_variation_name && $is_matching !=1 ) {
			
				if($wpdb->get_var("SHOW TABLES LIKE '".$wpdb->prefix."mt_woocommerce_fake_variations'") == $wpdb->prefix.'mt_woocommerce_fake_variations') {
					$wpdb->insert( 
						$table_name, 
						array( 
							'product_id' => $mt_wfvl_product_id, 
							'time' => date( 'Y-m-j' ), 
							'attribute_name' => $mt_wfvl_attribute_name, 
							'fake_variation_product_id' => $mt_wfvl_fake_variation, 
							'fake_variation_product_name' => $mt_wfvl_fake_variation_name, 
							'status' => $mt_wfvl_fake_variation_inactive, 
                            'mt_wfvl_fake_variation_type' => $mt_wfvl_fake_variation_type,
                            'mt_wfvl_fake_variation_color' => ($mt_wfvl_fake_variation_color) ? $mt_wfvl_fake_variation_color : '',
                            'mt_wfvl_fake_variation_image' => ($mt_wfvl_fake_variation_image) ? $mt_wfvl_fake_variation_image : '',
						) 
					);
				}

			 ?>
				<div class="notice notice-success is-dismissible">
					<p><?php esc_html_e("You have succesfuly added a new Fake Variation", "mt_wfvl");?></p>
				</div>
			<?php } elseif($is_matching == 1) { ?>
			 	<div class="notice notice-warning is-dismissible">
					<p><?php echo esc_html__("This Fake Variation already exists. You can not add it again.", "mt_wfvl");?></p>
				</div>
			<?php } else { ?>
				<div class="notice notice-warning is-dismissible">
					<p><?php echo esc_html__("You have to fill in all fields in order to add a new Fake Variation.", "mt_wfvl");?></p>
				</div>
			<?php }

    	}

		if (isset($_POST['remove_fake_variation'])) {
        	$fake_variation_id = $_POST["remove_fake_variation"];
			$wpdb->delete( $table_name, array( 'id' => $fake_variation_id ) );?>
			<div class="notice notice-info is-dismissible">
				<p><?php echo esc_html__("You have succesfuly removed a Fake Variation.", "mt_wfvl");?></p>
			</div>
        <?php }
        if (isset($_POST['inactive_variation'])) {
        	if($_POST['variation_status'] == 'inactive') {
				$wpdb->update( $table_name, array( 'status' => 'active'), array( 'id' => $_POST['inactive_variation'] ) ); ?>
				<div class="notice notice-success is-dismissible">
					<p><?php echo esc_html__("You have succesfuly activated a Fake Variation.", "mt_wfvl");?></p>
				</div>
        	<?php } elseif($_POST['variation_status'] == 'active') {
				$wpdb->update( $table_name, array( 'status' => 'inactive'), array( 'id' => $_POST['inactive_variation'] ) ); ?>
				<div class="notice notice-success is-dismissible">
					<p><?php echo esc_html__("You have succesfuly deactivated a Fake Variation.", "mt_wfvl");?></p>
				</div>
        	<?php }
        }

    }

    //function responsible for displaying the fake variation table
    function mt_wfvl_fake_variations_table() {
    	global $wpdb;
        $table_name = $wpdb->prefix . "mt_woocommerce_fake_variations";

    	$results = $wpdb->get_results( 
    		"SELECT * FROM ".$table_name."",
    		OBJECT
    	);
        $existing_products = wc_get_products(array('posts_per_page' => -1, 'post_status'=>'publish')); 
        $product_IDs = array();

        foreach ($existing_products as $product) {
            $product_IDs[] = $product->id;
        }
    	if(!empty($results)) { ?>
			<div class="wrap">
	        	<h2><?php echo esc_html__("MT Woocommerce Fake Variations Table", "mt_wfvl"); ?></h2>
	        	<table id="mt_woocommerce_fake_variations" class="table table-striped" style="width:100%">
	        		<thead>
	        			<tr>
	        				<th>
	        					<?php echo esc_html__("Product Title", "mt_wfvl") ?>
	        				</th>
	        				<th>
	        					<?php echo esc_html__("Atribute Name", "mt_wfvl") ?>
	        				</th>
	        				<th>
	        					<?php echo esc_html__("Linked Product", "mt_wfvl") ?>
	        				</th>
	        			    <th>
	        					<?php echo esc_html__("Variation label", "mt_wfvl") ?>
	        				</th>
                            <th>
                                <?php echo esc_html__("Variation Type", "mt_wfvl") ?>
                            </th>
	        			    <th>
	        					<?php echo esc_html__("Actions", "mt_wfvl") ?>
	        				</th>
	        			</tr>
	        		</thead>
	        		<tbody>
	        			<?php foreach ($results as $row) { 
                            if(in_array($row->product_id, $product_IDs) && in_array($row->fake_variation_product_id, $product_IDs)) {
    				    		$fake_variation_product = new Wc_Product($row->fake_variation_product_id);
    				    		$product = new Wc_Product($row->product_id);?>
    				    		<tr>
    				    			<td>
    				    				<?php echo '<a class="product_link" href="'.get_permalink( $row->product_id ).'"><img src="'.plugin_dir_url( __FILE__ ) .'/img/link.svg"></a><span product_id="'.esc_attr($row->product_id).'">'.esc_html($product->get_name()).'</span>'; ?>
    				    			</td>
    				    			<td>
    				    				<?php echo esc_html($row->attribute_name); ?>
    				    			</td>
    				    			<td>
    				    				<?php echo '<span fake_variation_product_id="'.esc_attr($row->fake_variation_product_id).'">'.esc_html($fake_variation_product->get_name()).'</span>'; ?>
    				    			</td>
    				    			<td>
    				    				<?php echo esc_html($row->fake_variation_product_name); ?>
    				    			</td>
                                    <td>
                                        <?php echo esc_html($row->mt_wfvl_fake_variation_type); ?>
                                    </td>
    				    			<td>
    				    				<form method="post">
                                            <input type="hidden" name="variation_status" value="<?php echo esc_attr($row->status); ?>" >
                                            <input type="hidden" name="variation_color" value="<?php echo esc_attr($row->mt_wfvl_fake_variation_color); ?>" >
    				    					<input type="hidden" name="variation_img" value="<?php echo esc_attr($row->mt_wfvl_fake_variation_image); ?>" >
    				    					<button class="button button-small" type="button" value="<?php echo esc_attr($row->id); ?>" name="edit-fake-variation" data-toggle="modal" data-target="#fake_edit_modal"><?php echo esc_html__("Edit", "mt_wfvl") ?></button>
    					    				<button type="submit" name="inactive_variation" value="<?php echo esc_attr($row->id); ?>" class="button button-small activate" <?php echo ($row->status == "active") ? "disabled" : "";?> ><?php esc_html_e("Activate", "mt_wfvl" ); ?></button>
    					    				<button type="submit" name="inactive_variation" value="<?php echo esc_attr($row->id); ?>" class="button button-small deactivate" <?php echo ($row->status == "inactive") ? "disabled" : "";?> ><?php esc_html_e("Deactivate", "mt_wfvl" ); ?></button>
    				    					<button type="hidden" name="remove_fake_variation" value="<?php echo esc_attr($row->id); ?>" class="button button-small"><?php esc_html_e("x", "mt_wfvl" ); ?></button>
    					    			</form>
    				    			</td>
    				    		</tr>
                            <?php } ?>
				    	<?php } ?>
	        		</tbody>
	        	</table>
	        </div>
    	<?php }    	
    }

    //function responsible for displaying the fake variation edit modal
    function mt_wfvl_fake_variations_edit_modal() { ?>
        <!-- Modal -->
		<div class="modal fade" id="fake_edit_modal" tabindex="-1" role="dialog" aria-labelledby="fake_variation_edit_modal" aria-hidden="true">
		  	<div class="modal-dialog modal-dialog-centered" role="document">
		    	<div class="modal-content">
		      		<div class="modal-header">
		        		<h3 class="modal-title" id="fake_variation_edit_modal"><?php echo esc_html__("Edit Fake Variation", "mt_wfvl") ?></h3>
		        		<button type="button" class="close btn btn-lg" data-dismiss="modal" aria-label="Close">
		          		<span aria-hidden="true">&times;</span>
		        		</button>
		      		</div>
		      		<div class="modal-body">
		      			<form method='post' action='<?= esc_url($_SERVER['REQUEST_URI']); ?>' enctype='multipart/form-data' class="edit_fake_variation">
		      				<table class="form-table" role="presentation">
		      					<tbody>
		      						<tr>
		      							<th scope="row"><?php echo esc_html__("Product Name:", "mt_wfvl"); ?></th>
		      							<td>
		      								<?php echo $this->mt_wfvl_products_name_droptdown(array('name'=>'mt_wfvl_edit_product_id')) ?>
			      						</td>
			      					</tr>
			      					<tr>
			      						<th scope="row"><?php echo esc_html__("Attribute name:", "mt_wfvl"); ?></th>
			      						<td>    	
			      							<?php echo $this->mt_wfvl_render_input_type_text(array('name'=>"mt_wfvl_edit_attribute_name", 'description'=>esc_html__("Example: Capacity", "mt_wfvl"))) ?>
    									</td>
    								</tr>
    								<tr>
    									<th scope="row"><?php echo esc_html__("Fake Variation Product:", "mt_wfvl"); ?></th>
    									<td>
    										<?php echo $this->mt_wfvl_products_name_droptdown(array('name'=>'mt_wfvl_edit_fake_variation')) ?>
    									</td>
    								</tr>
    								<tr>
    									<th scope="row"><?php echo esc_html__("Fake Variation name:", "mt_wfvl"); ?></th>
    									<td>    	
    										<?php echo $this->mt_wfvl_render_input_type_text(array('name'=>"mt_wfvl_edit_fake_variation_name",'description'=>esc_html__("Example: 64GB", "mt_wfvl"))) ?>
    									</td>
    								</tr>
                                    <tr>
                                        <th scope="row"><?php echo esc_html__("Fake Variation Type:", "mt_wfvl"); ?></th>
                                        <td>        
                                            <?php echo $this->mt_wfvl_fake_variations_type(array('name'=>"mt_wfvl_edit_fake_variation_type",'description'=>esc_html__("The type of the fake variation that will be seen in front end.", "mt_wfvl"))) ?>
                                        </td>
                                    </tr>
                                    <tr class="hidden">
                                        <th scope="row"><?php echo esc_html__("Fake Variation Image:", "mt_wfvl"); ?></th>
                                        <td>        
                                            <?php echo $this->mt_wfvl_fake_variations_image(array('name'=>"mt_wfvl_edit_fake_variation_image",'description'=>esc_html__("The image of the fake variation that will be seen in front end.", "mt_wfvl"))) ?>
                                        </td>
                                    </tr>
                                    <tr class="hidden">
                                        <th scope="row"><?php echo esc_html__("Fake Variation Color:", "mt_wfvl"); ?></th>
                                        <td>        
                                            <?php echo $this->mt_wfvl_fake_variations_color(array('name'=>"mt_wfvl_edit_fake_variation_color",'description'=>esc_html__("The color of the fake variation that will be seen in front end.", "mt_wfvl"))) ?>
                                        </td>
                                    </tr>
    								<tr>
    									<th scope="row"><?php echo esc_html__("Fake Variation Inactive:", "mt_wfvl"); ?></th>
    									<td><?php echo $this->mt_wfvl_render_input_type_checkbox(array('name'=>'mt_wfvl_edit_fake_variation_inactive')) ?></td>
									</tr>
    								</tbody>
    							</table>
    						<input type="hidden" name="variation_id" value="">
					  		<input type="submit" name="edit_fake_variation" value="Save Fake Variation" class="button-primary">
					  	</form>
		      		</div>
		   	 	</div>
		  	</div>
		</div>
    <?php }

    //function responsible for edditing the fake variation
    function mt_wfvl_edit_fake_variation() {
        if(isset($_POST['edit_fake_variation'])) {
            $mt_wfvl_fake_variation_type = NULL;
            $mt_wfvl_fake_variation_image = NULL;
            $mt_wfvl_fake_variation_color = NULL;

	    	global $wpdb;
            $table_name = $wpdb->prefix . "mt_woocommerce_fake_variations";

	        if (isset($_POST["mt_wfvl_edit_product_id"])) {
	        	$mt_wfvl_product_id = $_POST["mt_wfvl_edit_product_id"];
	        }
	        if (isset($_POST["mt_wfvl_edit_attribute_name"])) {
	        	$mt_wfvl_attribute_name = $_POST["mt_wfvl_edit_attribute_name"];
	        }
	        if (isset($_POST["mt_wfvl_edit_fake_variation"])) {
	        	$mt_wfvl_fake_variation = $_POST["mt_wfvl_edit_fake_variation"];
	        }
	        if (isset($_POST["mt_wfvl_edit_fake_variation_name"])) {
	        	$mt_wfvl_fake_variation_name = $_POST["mt_wfvl_edit_fake_variation_name"];
	        }
            if (isset($_POST["mt_wfvl_edit_fake_variation_type"])) {
                $mt_wfvl_fake_variation_type = $_POST["mt_wfvl_edit_fake_variation_type"];
            }
            if (isset($_POST["mt_wfvl_edit_fake_variation_image"])) {
                $mt_wfvl_fake_variation_image = $_POST["mt_wfvl_edit_fake_variation_image"];
            }
            if (isset($_POST["mt_wfvl_edit_fake_variation_color"])) {
                $mt_wfvl_fake_variation_color = $_POST["mt_wfvl_edit_fake_variation_color"];
            }
	        if (isset($_POST["mt_wfvl_edit_fake_variation_inactive"])) {
	        	$mt_wfvl_fake_variation_inactive = $_POST["mt_wfvl_edit_fake_variation_inactive"];
	        } else {
	        	$mt_wfvl_fake_variation_inactive = 'active';
	        }
	        $variation_id = $_POST['variation_id'];

	    	$results = $wpdb->get_results( 
	    		"SELECT * FROM ".$table_name."",
	    		OBJECT
	    	);

	    	$is_matching = 0;

			foreach ($results as $row) {
				if( $row->product_id == $mt_wfvl_product_id && $row->attribute_name == $mt_wfvl_attribute_name && $row->fake_variation_product_id == $mt_wfvl_fake_variation && $row->fake_variation_product_name == $mt_wfvl_fake_variation_name && $row->status == $mt_wfvl_fake_variation_inactive && $row->mt_wfvl_fake_variation_type == $mt_wfvl_fake_variation_type && $row->mt_wfvl_fake_variation_image == $mt_wfvl_fake_variation_image && $row->mt_wfvl_fake_variation_color == $mt_wfvl_fake_variation_color) {
					$is_matching = 1; 
				}
			}
			if($is_matching != 1) {
			
				if($wpdb->get_var("SHOW TABLES LIKE '".$wpdb->prefix."mt_woocommerce_fake_variations'") == $wpdb->prefix.'mt_woocommerce_fake_variations') {
					$wpdb->update( 
						$table_name, 
						array( 
							'product_id' => $mt_wfvl_product_id, 
							'time' => date( 'Y-m-j' ), 
							'attribute_name' => $mt_wfvl_attribute_name, 
							'fake_variation_product_id' => $mt_wfvl_fake_variation, 
							'fake_variation_product_name' => $mt_wfvl_fake_variation_name, 
							'status' => $mt_wfvl_fake_variation_inactive, 
                            'mt_wfvl_fake_variation_type' => $mt_wfvl_fake_variation_type,
                            'mt_wfvl_fake_variation_color' => ($mt_wfvl_fake_variation_color) ? $mt_wfvl_fake_variation_color : '',
                            'mt_wfvl_fake_variation_image' => ($mt_wfvl_fake_variation_image) ? $mt_wfvl_fake_variation_image : '',
						),
						array( 'id' => $variation_id ) 
					);
				} ?>
				<div class="notice notice-success is-dismissible">
					<p><?php echo esc_html__("You have succesfuly edited the Fake Variation", "mt_wfvl");?></p>
				</div>
				<?php 
			} elseif($is_matching == 1) {?>
				<div class="notice notice-warning is-dismissible">
					<p><?php echo esc_html__("This Fake Variation already exists. You can not add it again.", "mt_wfvl");?></p>
				</div>
			<?php

			}
        }
    }

    //function responsible for deleting fake variations when a product is deleted
    function mt_wfvl_delete_product($post_id) {
        global $wpdb;
        $product = get_post($post_id);
        if( $product->post_type != 'product') {
            return;
        }

        $table_name = $wpdb->prefix . "mt_woocommerce_fake_variations";
        $wpdb->delete( $table_name, array( 'product_id' => $post_id ) );
        $wpdb->delete( $table_name, array( 'fake_variation_product_name' => $post_id ) );

    }

}