<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://modeltheme.com/
 * @since             1.0.0
 * @package           Mt_Wfvl_Woocommerce_Fake_Variation_Links
 *
 * @wordpress-plugin
 * Plugin Name:       WooCommerce Fake Variation Links for Any Product Type
 * Plugin URI:        http://modeltheme.com/
 * Description:       Link products of any type in order to create fake variations for better visibility of your proucts.
 * Version:           1.2
 * Author:            ModelTheme
 * Author URI:        http://modeltheme.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       mt_wfvl
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'MT_WFVL_WOOCOMMERCE_FAKE_VARIATION_LINKS_VERSION', '1.1.6' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-mt-woocommerce-fake-variation-links-activator.php
 */
function mt_wfvl_activate_mt_wfvl_woocommerce_fake_variation_links() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-mt-woocommerce-fake-variation-links-activator.php';
	Mt_Wfvl_Woocommerce_Fake_Variation_Links_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-mt-woocommerce-fake-variation-links-deactivator.php
 */
function mt_wfvl_deactivate_mt_wfvl_woocommerce_fake_variation_links() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-mt-woocommerce-fake-variation-links-deactivator.php';
	Mt_Wfvl_Woocommerce_Fake_Variation_Links_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'mt_wfvl_activate_mt_wfvl_woocommerce_fake_variation_links' );
register_deactivation_hook( __FILE__, 'mt_wfvl_deactivate_mt_wfvl_woocommerce_fake_variation_links' );


//create "mt_woocommerce_fake_variations" db table
function mt_wfvl_create_database_table() {
	global $wpdb;
	$table_name = $wpdb->prefix . "mt_woocommerce_fake_variations";

	$charset_collate = $wpdb->get_charset_collate();

	$sql = "CREATE TABLE $table_name (
	  id mediumint(9) NOT NULL AUTO_INCREMENT,
	  product_id mediumint(9) NOT NULL,
	  attribute_name tinytext NOT NULL,
	  fake_variation_product_id mediumint(9) NOT NULL,
	  fake_variation_product_name tinytext NOT NULL,
	  status tinytext NOT NULL,
	  mt_wfvl_fake_variation_type tinytext NOT NULL, 
	  mt_wfvl_fake_variation_color tinytext,
	  mt_wfvl_fake_variation_image tinytext,
	  time datetime DEFAULT '0000-00-00' NOT NULL,
	  PRIMARY KEY  (id)
	) $charset_collate;";

	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );

}
//create "mt_woocommerce_fake_variations" db table at the plugin activation time
register_activation_hook( __FILE__, 'mt_wfvl_create_database_table' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-mt-woocommerce-fake-variation-links.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function mt_wfvl_run_mt_wfvl_woocommerce_fake_variation_links() {

	$plugin = new Mt_Wfvl_Woocommerce_Fake_Variation_Links();
	$plugin->run();

}
mt_wfvl_run_mt_wfvl_woocommerce_fake_variation_links();


add_action( 'wp_ajax_mtAjaxSearchTitleSku', 'mt_wfvl_get_select2_products_ajax_callback' ); // wp_ajax_{action}
function mt_wfvl_get_select2_products_ajax_callback(){

    // we will pass post IDs and titles to this array
    $return = array();

    $search_keyword = $_GET['q'];

    $q1 = new WP_Query( 
        array( 
            's'=> $search_keyword, // the search query
            'post_status' => 'publish', // if you don't want drafts to be returned
            'post_type' => 'product', // if you don't want drafts to be returned
            'posts_per_page' => 50
        )
    );

    $q2 = new WP_Query(
        array( 
            'post_status' => 'publish', // if you don't want drafts to be returned
            'post_type' => 'product', // if you don't want drafts to be returned
            'posts_per_page' => 50, // how much to show at once
            'meta_query' => array(
                array(
                    'key' => '_sku',
                    'value' => $_GET['q'],
                    'compare' => 'LIKE'
                )
            )
        )
    );

    $result = new WP_Query();
    $result->posts = array_unique( array_merge( $q1->posts, $q2->posts ), SORT_REGULAR );

    if ($result->posts) {
        foreach ($result->posts as $product) {
            // var_dump($product->ID);
            $return[] = array( $product->ID, $product->post_title ); // array( Post ID, Post Title )
        }
    }

    echo json_encode( $return );
    die;
}

