<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://modeltheme.com/
 * @since      1.0.0
 *
 * @package    Mt_Wfvl_Woocommerce_Fake_Variation_Links
 * @subpackage Mt_Wfvl_Woocommerce_Fake_Variation_Links/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Mt_Wfvl_Woocommerce_Fake_Variation_Links
 * @subpackage Mt_Wfvl_Woocommerce_Fake_Variation_Links/public
 * @author     ModelTheme <support@modeltheme.com>
 */
class Mt_Wfvl_Woocommerce_Fake_Variation_Links_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Mt_Wfvl_Woocommerce_Fake_Variation_Links_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Mt_Wfvl_Woocommerce_Fake_Variation_Links_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/mt-woocommerce-fake-variation-links-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Mt_Wfvl_Woocommerce_Fake_Variation_Links_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Mt_Wfvl_Woocommerce_Fake_Variation_Links_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/mt-woocommerce-fake-variation-links-public.js', array( 'jquery' ), $this->version, false );

	}
	
	// define the woocommerce_before_add_to_cart_button callback 
	// adds attribute list on single product
	function mt_wfvl_fake_variations_list() { 
		global $wpdb;
	    $fake_variation = $wpdb->get_results( 
    		"SELECT * FROM ".$wpdb->prefix."mt_woocommerce_fake_variations 
    		WHERE product_id = '".get_the_ID()."'", 
    		OBJECT
    	);
    	$existing_products = wc_get_products(array('posts_per_page' => -1, 'post_status'=>'publish')); 
		$product_IDs = array();

		foreach ($existing_products as $product) {
			$product_IDs[] = $product->get_id();
		}
	    $fake_variations_array = array();
    	foreach ($fake_variation as $fake_variation) {
    		$existing_attribute = array();
    		$attribute_name = $fake_variation->attribute_name;
    		if( array_key_exists ( $attribute_name ,  $fake_variations_array ) ) {
    			$existing_attribute = $fake_variations_array[ $attribute_name ];
    			$existing_attribute[] = array('fake_variation_id' => $fake_variation->fake_variation_product_id, 'fake_variation_name' => $fake_variation->fake_variation_product_name , 'fake_variation_status' => $fake_variation->status, 'fake_variation_type' => $fake_variation->mt_wfvl_fake_variation_type, 'fake_variation_color' => $fake_variation->mt_wfvl_fake_variation_color, 'fake_variation_image' => $fake_variation->mt_wfvl_fake_variation_image);
    			$fake_variations_array[ $attribute_name ] = $existing_attribute;
    		} else {
    			$fake_variations_array[ $attribute_name ] = array( array('fake_variation_id' => $fake_variation->fake_variation_product_id, 'fake_variation_name' => $fake_variation->fake_variation_product_name , 'fake_variation_status' => $fake_variation->status, 'fake_variation_type' => $fake_variation->mt_wfvl_fake_variation_type, 'fake_variation_color' => $fake_variation->mt_wfvl_fake_variation_color, 'fake_variation_image' => $fake_variation->mt_wfvl_fake_variation_image ) );
    		}
    	}
    	ksort($fake_variations_array);
        echo '<div class="mt-fake-variations-group">';
    	foreach($fake_variations_array as $key => $fake_variation_name) {
    		echo '<div class="mt-fake-category">';
	    		echo '<label class="mt-fake-category-name">'.esc_html($key).'</label>';
	    		echo '<ul class="mt-fake-variations">';
	    		foreach ($fake_variation_name as $fake_variation) {
	    			if(in_array($fake_variation['fake_variation_id'], $product_IDs)) {
	    				if ($fake_variation['fake_variation_type'] == "text") {
			    			echo '<li class="mt-fake-variation"><a href="'.get_the_permalink(esc_attr( $fake_variation['fake_variation_id'] )).'" class="'.esc_attr($fake_variation['fake_variation_status']).' '.(get_the_ID() == $fake_variation['fake_variation_id'] ? "current" : "").'">'.esc_html($fake_variation['fake_variation_name']).'</a></li>';
	    				} elseif($fake_variation['fake_variation_type'] == "image") {
	    					echo '<li class="mt-fake-variation image"><a href="'.get_the_permalink(esc_attr( $fake_variation['fake_variation_id'] )).'" class="'.esc_attr($fake_variation['fake_variation_status']).' '.(get_the_ID() == $fake_variation['fake_variation_id'] ? "current" : "").'"><img src="'.esc_html(wp_get_attachment_image_src($fake_variation['fake_variation_image'])[0]).'"><span>'.esc_html($fake_variation['fake_variation_name']).'</span></a></li>';
	    				} elseif($fake_variation['fake_variation_type'] == "color") {
	    					echo '<li class="mt-fake-variation color"><a href="'.get_the_permalink(esc_attr( $fake_variation['fake_variation_id'] )).'" class="'.esc_attr($fake_variation['fake_variation_status']).' '.(get_the_ID() == $fake_variation['fake_variation_id'] ? "current" : "").'" style="background-color:'.esc_html($fake_variation['fake_variation_color']).'"></a></li>';
	    				} else {
	    					echo '<li class="mt-fake-variation"><a href="'.get_the_permalink(esc_attr( $fake_variation['fake_variation_id'] )).'" class="'.esc_attr($fake_variation['fake_variation_status']).' '.(get_the_ID() == $fake_variation['fake_variation_id'] ? "current" : "").'">'.esc_html($fake_variation['fake_variation_name']).'</a></li>';
	    				}
		    		}
	    		}
	    		echo '</ul>';
    		echo '</div>';
    	}
		echo '</div>';
	}

	//function responsible for hooking the above function to the value from the location admin field
	function mt_wfvl_fake_variations_list_display() {
		add_action(get_option('fake_variation_hook', 'woocommerce_after_add_to_cart_button'), array($this, 'mt_wfvl_fake_variations_list'), 10, 1);
	} 

}
